diff --git a/doc/source/reference/kwant.system.rst b/doc/source/reference/kwant.system.rst
index 3fc95f497c05b5ced29ce95f9665ab1d8f1b74dd..3b6f26274da393807c37c6c2826ce5518fe41c7d 100644
--- a/doc/source/reference/kwant.system.rst
+++ b/doc/source/reference/kwant.system.rst
@@ -14,6 +14,11 @@ Any system which is provided to a solver should be derived from the appropriate
 class in this module, and every solver can assume that its input corresponds to
 the interface defined here.
 
+In practice, very often Kwant systems are finalized
+`builders <kwant.builder.Builder>` (i.e.
+`kwant.builder.FiniteSystem` or `kwant.builder.InfiniteSystem`) and offer some
+additional attributes.
+
 .. autosummary::
    :toctree: generated/
 
diff --git a/kwant/builder.py b/kwant/builder.py
index 1418b40ae86678d91f64034dd58a7669725c24d1..ccb8f82fa6d1126b7a7d83f33c29551f8ffcab46 100644
--- a/kwant/builder.py
+++ b/kwant/builder.py
@@ -538,9 +538,10 @@ class Lead(metaclass=abc.ABCMeta):
 
         Notes
         -----
-        The finalized lead must be an object that can be used as a lead in a
-        `kwant.system.FiniteSystem`.  It could be an instance of
-        `kwant.system.InfiniteSystem` for example.
+        The finalized lead must be an object that can be used as a lead
+        in a `kwant.system.FiniteSystem`, i.e. an instance of
+        `kwant.system.InfiniteSystem`.  Typically it will be a finalized
+        builder: `kwant.builder.InfiniteSystem`.
 
         The order of sites for the finalized lead must be the one specified in
         `interface`.
@@ -584,7 +585,7 @@ class BuilderLead(Lead):
         self.interface = tuple(sorted(interface))
 
     def finalized(self):
         """Return a `kwant.system.InfiniteSystem` corresponding to the
         compressed lead.
 
         The order of interface sites is kept during finalization.
@@ -1603,9 +1604,9 @@ class Builder:
 
         Returns
         -------
-        finalized_system : `kwant.system.FiniteSystem`
+        finalized_system : `kwant.builder.FiniteSystem`
             If there is no symmetry.
-        finalized_system : `kwant.system.InfiniteSystem`
+        finalized_system : `kwant.builder.InfiniteSystem`
             If a symmetry is present.
 
         Notes
@@ -584,7 +585,7 @@ class BuilderLead(Lead):
 
     def finalized(self):
-        """Return a `kwant.system.InfiniteSystem` corresponding to the
+        """Return a `kwant.builder.InfiniteSystem` corresponding to the
         compressed lead.
 